Ethereal->Wireshark
authoretxrab <etxrab@f5534014-38df-0310-8fa8-9805f1628bb7>
Sun, 28 May 2006 20:28:20 +0000 (20:28 +0000)
committeretxrab <etxrab@f5534014-38df-0310-8fa8-9805f1628bb7>
Sun, 28 May 2006 20:28:20 +0000 (20:28 +0000)
git-svn-id: http://anonsvn.wireshark.org/wireshark/trunk@18235 f5534014-38df-0310-8fa8-9805f1628bb7

45 files changed:
alert_box.c
capinfos.c
capture-pcap-util.c
capture-wpcap.c
capture.c
capture_errs.c
capture_info.c
capture_loop.c
capture_loop.h
capture_opts.c
capture_sync.c
capture_sync.h
capture_wpcap_packet.c
clopts_common.c
clopts_common.h
dumpcap.c
editcap.c
file.c
isprint.h
mergecap.c
print.c
rdps.c
snprintf.h
tap-afpstat.c
tap-bootpstat.c
tap-dcerpcstat.c
tap-h225counter.c
tap-h225rassrt.c
tap-httpstat.c
tap-iostat.c
tap-iousers.c
tap-mgcpstat.c
tap-protocolinfo.c
tap-protohierstat.c
tap-rpcprogs.c
tap-rpcstat.c
tap-sctpchunkstat.c
tap-sipstat.c
tap-smbsids.c
tap-smbstat.c
tap-stats_tree.c
tap-wspstat.c
tethereal.c
text2pcap.c
version_info.c

index 966b002e5716f52210a54c6b12bfe3cd9250b112..1ac91e2337773f2176b12baf133ff71f0f84d9b2 100644 (file)
@@ -57,7 +57,7 @@ failure_alert_box(const char *msg_format, va_list ap)
  * various HIGs suggest that you should, for example, suggest that the
  * user remove files if the file system is full.  Perhaps that's because
  * they're providing guidelines for people less sophisticated than the
- * typical Ethereal user is, but....
+ * typical Wireshark user is, but....
  */
 void
 open_failure_alert_box(const char *filename, int err, gboolean for_writing)
@@ -86,7 +86,7 @@ read_failure_alert_box(const char *filename, int err)
  * various HIGs suggest that you should, for example, suggest that the
  * user remove files if the file system is full.  Perhaps that's because
  * they're providing guidelines for people less sophisticated than the
- * typical Ethereal user is, but....
+ * typical Wireshark user is, but....
  */
 void
 write_failure_alert_box(const char *filename, int err)
index 4aa6b69b201a45dd352a3d39c71df574f5a812cf..71830439ff4cced669201c891a199b2fb595b3bd 100644 (file)
@@ -216,7 +216,7 @@ static void usage(gboolean is_error)
 #endif
          "\n", VERSION);
   fprintf(output, "Prints information about capture files.\n");
-  fprintf(output, "See http://www.ethereal.com for more information.\n");
+  fprintf(output, "See http://www.wireshark.org for more information.\n");
   fprintf(output, "\n");
   fprintf(output, "Usage: capinfos [options] <infile> ...\n");
   fprintf(output, "\n");
index ed7b2f3d135d846fc661294645a35133895cd9b7..f62d0adacc16a9704400081bf9a9d5d1187138e8 100644 (file)
@@ -105,11 +105,11 @@ get_pcap_linktype(pcap_t *pch, const char *devname
         * value, rather than as a DLT_ value, we will assume this is AIX's
         * non-standard, incompatible libpcap, rather than a standard libpcap,
         * and will map the link-layer type to the standard DLT_ value for
-        * that link-layer type, as that's what the rest of Ethereal expects.
+        * that link-layer type, as that's what the rest of Wireshark expects.
         *
         * (This means the capture files won't be readable by a tcpdump
         * linked with AIX's non-standard libpcap, but so it goes.  They
-        * *will* be readable by standard versions of tcpdump, Ethereal,
+        * *will* be readable by standard versions of tcpdump, Wireshark,
         * and so on.)
         *
         * XXX - if we conclude we're using AIX libpcap, should we also
@@ -141,7 +141,7 @@ get_pcap_linktype(pcap_t *pch, const char *devname
                        /*
                         * That's the RFC 1573 value for 802.3; map it to
                         * DLT_EN10MB.
-                        * (libpcap, tcpdump, Ethereal, etc. don't care if
+                        * (libpcap, tcpdump, Wireshark, etc. don't care if
                         * it's Ethernet or 802.3.)
                         */
                        linktype = 1;
index bb0606735222c62c9b48ea5bbead15c33153401d..643cf5d575a46d118ac0fe56c78803f984ddaa30 100644 (file)
@@ -1,6 +1,6 @@
 /* capture-wpcap.c
  * WinPcap-specific interfaces for capturing.  We load WinPcap at run
- * time, so that we only need one Ethereal binary and one Tethereal binary
+ * time, so that we only need one Wireshark binary and one Twireshark binary
  * for Windows, regardless of whether WinPcap is installed or not.
  *
  * $Id$
index 6e9e39d0616a59cd0b5b10080d2e108a1d0856b4..f412e6c866a6478ea709995529c8ae95d2c0a488 100644 (file)
--- a/editcap.c
+++ b/editcap.c
@@ -236,7 +236,7 @@ static void usage(void)
 #endif
          "\n", VERSION);
   fprintf(stderr, "Edit and/or translate the format of capture files.\n");
-  fprintf(stderr, "See http://www.ethereal.com for more information.\n");
+  fprintf(stderr, "See http://www.wireshark.org for more information.\n");
   fprintf(stderr, "\n");
   fprintf(stderr, "Usage: editcap [options] ... <infile> <outfile> [ <packet#>[-<packet#>] ... ]\n");
   fprintf(stderr, "\n");
diff --git a/print.c b/print.c
index 35a66e3791611cb9ce258a8478e189d867158f84..4c1f019aec9c62383a98e82bf13b47fc058286b8 100644 (file)
--- a/print.c
+++ b/print.c
@@ -998,7 +998,7 @@ print_preamble_ps(print_stream_t *self, gchar *filename)
        fputs("\n", output->fh);
        fputs("%% the page title\n", output->fh);
        ps_clean_string(psbuffer, filename, MAX_PS_LINE_LENGTH);
-       fprintf(output->fh, "/eth_pagetitle (%s - Ethereal) def\n", psbuffer);
+       fprintf(output->fh, "/eth_pagetitle (%s - Wireshark) def\n", psbuffer);
        fputs("\n", output->fh);
        return !ferror(output->fh);
 }
diff --git a/rdps.c b/rdps.c
index 1830ae80ac77befe9012099b2544d28f51bac974..9cd0924b279d78f10d7b58acc8caaaeb859fa248 100644 (file)
--- a/rdps.c
+++ b/rdps.c
@@ -76,19 +76,19 @@ int main(int argc, char **argv)
        while (fgets(buf, BUFFER_SIZE - 1, input)) {
 
                if (state == null) {
-                       if (strcmp(buf, "% ---- ethereal preamble start ---- %\n") == 0) {
+                       if (strcmp(buf, "% ---- wireshark preamble start ---- %\n") == 0) {
                                state = preamble;
                                start_code(output, "preamble");
                                continue;
                        }
-                       else if (strcmp(buf, "% ---- ethereal finale start ---- %\n") == 0) {
+                       else if (strcmp(buf, "% ---- wireshark finale start ---- %\n") == 0) {
                                state = finale;
                                start_code(output, "finale");
                                continue;
                        }
                }
                else if (state == preamble) {
-                       if (strcmp(buf, "% ---- ethereal preamble end ---- %\n") == 0) {
+                       if (strcmp(buf, "% ---- wireshark preamble end ---- %\n") == 0) {
                                state = null;
                                end_code(output);
                                continue;
@@ -98,7 +98,7 @@ int main(int argc, char **argv)
                        }
                }
                else if (state == hex) {
-                       if (strcmp(buf, "% ---- ethereal hex end ---- %\n") == 0) {
+                       if (strcmp(buf, "% ---- wireshark hex end ---- %\n") == 0) {
                                state = null;
                                end_code(output);
                                continue;
@@ -108,7 +108,7 @@ int main(int argc, char **argv)
                        }
                }
                else if (state == finale) {
-                       if (strcmp(buf, "% ---- ethereal finale end ---- %\n") == 0) {
+                       if (strcmp(buf, "% ---- wireshark finale end ---- %\n") == 0) {
                                state = null;
                                end_code(output);
                                continue;
index b1553e4349643c68e3d4872d96330d4b2e658d1b..45d2b3ba97ee91de9b84ff870951b9bde2edea34 100644 (file)
@@ -2,8 +2,8 @@
  * $Id$
  */
 
-#ifndef __ETHEREAL_SNPRINTF_H__
-#define __ETHEREAL_SNPRINTF_H__
+#ifndef __WIRESHARK_SNPRINTF_H__
+#define __WIRESHARK_SNPRINTF_H__
 
 #if defined(HAVE_STDARG_H)
 # include <stdarg.h>
index 0b3b54dbe7aba049fac7617bd47a03e6f608019e..d41e3782c61ce933cfa6fb0f5c3cd7d911413cbe 100644 (file)
@@ -157,7 +157,7 @@ afpstat_init(const char *optarg, void* userdata _U_)
                g_free(ss->filter);
                g_free(ss);
 
-               fprintf(stderr, "tethereal: Couldn't register afp,rtt tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register afp,rtt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 0273b0055225971d258d3fc0c5cab0ff421ab9ec..bbb450d18a2f679be9c4496f6ca758d6a526393f 100644 (file)
@@ -170,7 +170,7 @@ dhcpstat_init(const char *optarg, void* userdata _U_)
                /* error, we failed to attach to the tap. clean up */
                g_free(sp->filter);
                g_free(sp);
-               fprintf(stderr, "tethereal: Couldn't register dhcp,stat tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register dhcp,stat tap: %s\n",
                                error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index e5f990ee9c374cacc5645016f3ff4b20bcaaba06..a15f18209d38644ee1adfda41b047d84221dd68a 100644 (file)
@@ -229,15 +229,15 @@ dcerpcstat_init(const char *optarg, void* userdata _U_)
                        filter=NULL;
                }
        } else {
-               fprintf(stderr, "tethereal: invalid \"-z dcerpc,rtt,<uuid>,<major version>.<minor version>[,<filter>]\" argument\n");
+               fprintf(stderr, "twireshark: invalid \"-z dcerpc,rtt,<uuid>,<major version>.<minor version>[,<filter>]\" argument\n");
                exit(1);
        }
        if (major < 0 || major > 65535) {
-               fprintf(stderr,"tethereal: dcerpcstat_init() Major version number %d is invalid - must be positive and <= 65535\n", major);
+               fprintf(stderr,"twireshark: dcerpcstat_init() Major version number %d is invalid - must be positive and <= 65535\n", major);
                exit(1);
        }
        if (minor < 0 || minor > 65535) {
-               fprintf(stderr,"tethereal: dcerpcstat_init() Minor version number %d is invalid - must be positive and <= 65535\n", minor);
+               fprintf(stderr,"twireshark: dcerpcstat_init() Minor version number %d is invalid - must be positive and <= 65535\n", minor);
                exit(1);
        }
        ver = major;
@@ -246,7 +246,7 @@ dcerpcstat_init(const char *optarg, void* userdata _U_)
        rs->prog=dcerpc_get_proto_name(&uuid, ver);
        if(!rs->prog){
                g_free(rs);
-               fprintf(stderr,"tethereal: dcerpcstat_init() Protocol with uuid:%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x v%u not supported\n",uuid.Data1,uuid.Data2,uuid.Data3,uuid.Data4[0],uuid.Data4[1],uuid.Data4[2],uuid.Data4[3],uuid.Data4[4],uuid.Data4[5],uuid.Data4[6],uuid.Data4[7],ver);
+               fprintf(stderr,"twireshark: dcerpcstat_init() Protocol with uuid:%08x-%04x-%04x-%02x%02x-%02x%02x%02x%02x%02x%02x v%u not supported\n",uuid.Data1,uuid.Data2,uuid.Data3,uuid.Data4[0],uuid.Data4[1],uuid.Data4[2],uuid.Data4[3],uuid.Data4[4],uuid.Data4[5],uuid.Data4[6],uuid.Data4[7],ver);
                exit(1);
        }
        procs=dcerpc_get_proto_sub_dissector(&uuid, ver);
@@ -291,7 +291,7 @@ dcerpcstat_init(const char *optarg, void* userdata _U_)
                g_free(rs->filter);
                g_free(rs);
 
-               fprintf(stderr, "tethereal: Couldn't register dcerpc,rtt tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register dcerpc,rtt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 4735882e1a43ddedc966505a3b940be4680bfc4f..d518913972cd29dfcc7a9c738498c0899a614079 100644 (file)
@@ -1,5 +1,5 @@
 /* tap_h225counter.c
- * h225 message counter for ethereal
+ * h225 message counter for wireshark
  * Copyright 2003 Lars Roland
  *
  * $Id$
@@ -412,7 +412,7 @@ h225counter_init(const char *optarg, void* userdata _U_)
                g_free(hs->filter);
                g_free(hs);
 
-               fprintf(stderr, "tethereal: Couldn't register h225,counter tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register h225,counter tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 955a2c6f64d8094ac96c66a204c8d640050a0f7c..7158a726928f57d4d2e64a60d4a1aeed208fa1ae 100644 (file)
@@ -1,5 +1,5 @@
 /* tap_h225rassrt.c
- * h225 RAS Service Response Time statistics for ethereal
+ * h225 RAS Service Response Time statistics for wireshark
  * Copyright 2003 Lars Roland
  *
  * $Id$
@@ -236,7 +236,7 @@ h225rassrt_init(const char *optarg, void* userdata _U_)
                g_free(hs->filter);
                g_free(hs);
 
-               fprintf(stderr, "tethereal: Couldn't register h225,srt tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register h225,srt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index c9fc4e352de60ccfa4648de159470ff84e6af330..fc2a16868122150affa38829574e4b57cf629313 100644 (file)
@@ -314,7 +314,7 @@ gtk_httpstat_init(const char *optarg,void* userdata _U_)
                /* error, we failed to attach to the tap. clean up */
                g_free(sp->filter);
                g_free(sp);
-               fprintf (stderr, "tethereal: Couldn't register http,stat tap: %s\n",
+               fprintf (stderr, "twireshark: Couldn't register http,stat tap: %s\n",
                                error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 439d586cd8d367e56fcab35318b9b0bdbd0e9866..8ad4a3c2e1b0afaf47d54cecd9dfe4db053b7853 100644 (file)
@@ -479,18 +479,18 @@ register_io_tap(io_stat_t *io, int i, const char *filter)
                        p=filter+namelen+1;
                        parenp=strchr(p, ')');
                        if(!parenp){
-                               fprintf(stderr, "tethereal: Closing parenthesis missing from calculated expression.\n");
+                               fprintf(stderr, "twireshark: Closing parenthesis missing from calculated expression.\n");
                                exit(10);
                        }
                        /* bail out if there was no field specified */
                        if(parenp==p){
-                               fprintf(stderr, "tethereal: You didn't specify a field name for %s(*).\n",
+                               fprintf(stderr, "twireshark: You didn't specify a field name for %s(*).\n",
                                    calc_type_table[j].func_name);
                                exit(10);
                        }
                        field=malloc(parenp-p+1);
                        if(!field){
-                               fprintf(stderr, "tethereal: Out of memory.\n");
+                               fprintf(stderr, "twireshark: Out of memory.\n");
                                exit(10);
                        }
                        memcpy(field, p, parenp-p);
@@ -499,7 +499,7 @@ register_io_tap(io_stat_t *io, int i, const char *filter)
 
                        hfi=proto_registrar_get_byname(field);
                        if(!hfi){
-                               fprintf(stderr, "tethereal: There is no field named '%s'.\n",
+                               fprintf(stderr, "twireshark: There is no field named '%s'.\n",
                                    field);
                                free(field);
                                exit(10);
@@ -533,7 +533,7 @@ register_io_tap(io_stat_t *io, int i, const char *filter)
                                break;
                        default:
                                fprintf(stderr,
-                                   "tethereal: %s is a relative-time field, so %s(*) calculations are not supported on it.",
+                                   "twireshark: %s is a relative-time field, so %s(*) calculations are not supported on it.",
                                    field,
                                    calc_type_table[j].func_name);
                                exit(10);
@@ -547,7 +547,7 @@ register_io_tap(io_stat_t *io, int i, const char *filter)
                         */
                        if(io->items[i].calc_type!=CALC_TYPE_COUNT){
                                fprintf(stderr,
-                                   "tethereal: %s is a 64-bit integer, so %s(*) calculations are not supported on it.",
+                                   "twireshark: %s is a 64-bit integer, so %s(*) calculations are not supported on it.",
                                    field,
                                    calc_type_table[j].func_name);
                                exit(10);
@@ -560,7 +560,7 @@ register_io_tap(io_stat_t *io, int i, const char *filter)
                         */
                        if(io->items[i].calc_type!=CALC_TYPE_COUNT){
                                fprintf(stderr,
-                                   "tethereal: %s doesn't have integral values, so %s(*) calculations are not supported on it.\n",
+                                   "twireshark: %s doesn't have integral values, so %s(*) calculations are not supported on it.\n",
                                    field,
                                    calc_type_table[j].func_name);
                                exit(10);
@@ -581,7 +581,7 @@ CALC_TYPE_AVG       5
        if(error_string){
                g_free(io->items);
                g_free(io);
-               fprintf(stderr, "tethereal: Couldn't register io,stat tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register io,stat tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
@@ -604,7 +604,7 @@ iostat_init(const char *optarg, void* userdata _U_)
                        filter=NULL;
                }
        } else {
-               fprintf(stderr, "tethereal: invalid \"-z io,stat,<interval>[,<filter>]\" argument\n");
+               fprintf(stderr, "twireshark: invalid \"-z io,stat,<interval>[,<filter>]\" argument\n");
                exit(1);
        }
 
@@ -612,7 +612,7 @@ iostat_init(const char *optarg, void* userdata _U_)
        /* make interval be number of ms */
        interval=(gint32)(interval_float*1000.0+0.9);   
        if(interval<1){
-               fprintf(stderr, "tethereal: \"-z\" interval must be >=0.001 seconds.\n");
+               fprintf(stderr, "twireshark: \"-z\" interval must be >=0.001 seconds.\n");
                exit(10);
        }
        
index 1e8d42fc9139a0fec36db098ad1f05b8c3da6539..029a7ec737a70d64d36ba342cfb14b7c143537dc 100644 (file)
@@ -671,7 +671,7 @@ iousers_init(const char *optarg, void* userdata _U_)
                tap_type_name="SCTP";
                packet_func=iousers_sctp_packet;
        } else {
-               fprintf(stderr, "tethereal: invalid \"-z conv,<type>[,<filter>]\" argument\n");
+               fprintf(stderr, "twireshark: invalid \"-z conv,<type>[,<filter>]\" argument\n");
                fprintf(stderr,"   <type> must be one of\n");
                fprintf(stderr,"      \"eth\"\n");
                fprintf(stderr,"      \"fc\"\n");
@@ -701,7 +701,7 @@ iousers_init(const char *optarg, void* userdata _U_)
                        g_free(iu->items);
                }
                g_free(iu);
-               fprintf(stderr, "tethereal: Couldn't register conversations tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register conversations tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index f14a5283bad8654654341c13824c002006bafdf2..080113daa3b07469f8e028ab532232d82999a0bf 100644 (file)
@@ -217,7 +217,7 @@ mgcpstat_init(const char *optarg, void* userdata _U_)
                g_free(ms->filter);
                g_free(ms);
 
-               fprintf(stderr, "tethereal: Couldn't register mgcp,rtd tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register mgcp,rtd tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index af8146374550317d6a201f1dfcdd079a8284b8de..3f4cc3108b8dc28b4c22d380eee746079c39cebe 100644 (file)
@@ -22,7 +22,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-/* This module provides Protocol Column Info tap for tethereal */
+/* This module provides Protocol Column Info tap for twireshark */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -67,7 +67,7 @@ protocolinfo_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt, const vo
         * and, if so, we report that error and exit.
         */
        if (pinfo->cinfo == NULL) {
-               fprintf(stderr, "tethereal: the proto,colinfo tap doesn't work if the columns aren't being printed.\n");
+               fprintf(stderr, "twireshark: the proto,colinfo tap doesn't work if the columns aren't being printed.\n");
                exit(1);
        }
        gp=proto_get_finfo_ptr_array(edt->tree, rs->hf_index);
@@ -103,13 +103,13 @@ protocolinfo_init(const char *optarg, void* userdata _U_)
                }
        }
        if(!field){
-               fprintf(stderr, "tethereal: invalid \"-z proto,colinfo,<filter>,<field>\" argument\n");
+               fprintf(stderr, "twireshark: invalid \"-z proto,colinfo,<filter>,<field>\" argument\n");
                exit(1);
        }
 
        hfi=proto_registrar_get_byname(field);
        if(!hfi){
-               fprintf(stderr, "tethereal: Field \"%s\" doesn't exist.\n", field);
+               fprintf(stderr, "twireshark: Field \"%s\" doesn't exist.\n", field);
                exit(1);
        }
 
@@ -126,7 +126,7 @@ protocolinfo_init(const char *optarg, void* userdata _U_)
        error_string=register_tap_listener("frame", rs, rs->filter, NULL, protocolinfo_packet, NULL);
        if(error_string){
                /* error, we failed to attach to the tap. complain and clean up */
-               fprintf(stderr, "tethereal: Couldn't register proto,colinfo tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register proto,colinfo tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                if(rs->filter){
index 07e14c28c8fc38ff7ec7f0ac220460f5289528b0..19615cb5cc0294fd3aedc193ff8e52106c211b8f 100644 (file)
@@ -22,7 +22,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-/* This module provides ProtocolHierarchyStatistics for tethereal */
+/* This module provides ProtocolHierarchyStatistics for twireshark */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -193,7 +193,7 @@ protohierstat_init(const char *optarg, void* userdata _U_)
                        filter="frame"; 
                }
        } else {
-               fprintf(stderr, "tethereal: invalid \"-z io,phs[,<filter>]\" argument\n");
+               fprintf(stderr, "twireshark: invalid \"-z io,phs[,<filter>]\" argument\n");
                exit(1);
        }
 
@@ -212,7 +212,7 @@ protohierstat_init(const char *optarg, void* userdata _U_)
                g_free(rs->filter);
                g_free(rs);
 
-               fprintf(stderr, "tethereal: Couldn't register io,phs tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register io,phs tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index ab84e6983509439801e590a9748174253554d1df..15517517fbc8378984fcdcfdb2a7b1d3f540d9d3 100644 (file)
@@ -22,8 +22,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-/* This module provides rpc call/reply SRT statistics to tethereal.
- * It is only used by tethereal and not ethereal
+/* This module provides rpc call/reply SRT statistics to twireshark.
+ * It is only used by twireshark and not wireshark
  */
 
 #ifdef HAVE_CONFIG_H
@@ -227,7 +227,7 @@ rpcprogs_init(const char *optarg _U_, void* userdata _U_)
 
        error_string=register_tap_listener("rpc", NULL, NULL, NULL, rpcprogs_packet, rpcprogs_draw);
        if(error_string){
-               fprintf(stderr,"tethereal: Couldn't register rpc,programs tap: %s\n",
+               fprintf(stderr,"twireshark: Couldn't register rpc,programs tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 5f0ccbbb6af4f3fb308dbe179714a3fac3f1741b..d9799803ccae05946023ba02af45a00998056201 100644 (file)
@@ -22,8 +22,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-/* This module provides rpc call/reply RTT statistics to tethereal.
- * It is only used by tethereal and not ethereal
+/* This module provides rpc call/reply RTT statistics to twireshark.
+ * It is only used by twireshark and not wireshark
  *
  * It serves as an example on how to use the tap api.
  */
@@ -66,11 +66,11 @@ typedef struct _rpcstat_t {
 
 
 
-/* This callback is never used by tethereal but it is here for completeness.
+/* This callback is never used by twireshark but it is here for completeness.
  * When registering below, we could just have left this function as NULL.
  *
  * When used by wireshark, this function will be called whenever we would need
- * to reset all state. Such as when ethereal opens a new file, when it
+ * to reset all state. Such as when wireshark opens a new file, when it
  * starts a new capture, when it rescans the packetlist after some prefs have
  * changed etc.
  * So if your aplication has some state it needs to clean up in those
@@ -102,7 +102,7 @@ rpcstat_reset(void *prs)
  * later.
  *
  * This function should be as lightweight as possible since it executes together
- * with the normal ethereal dissectors. Try to push as much processing as
+ * with the normal wireshark dissectors. Try to push as much processing as
  * possible into (*draw) instead since that function executes asynchronously
  * and does not affect the main threads performance.
  *
@@ -186,10 +186,10 @@ rpcstat_packet(void *prs, packet_info *pinfo, epan_dissect_t *edt _U_, const voi
        return 1;
 }
 
-/* This callback is used when tethereal wants us to draw/update our
- * data to the output device. Since this is tethereal only output is
+/* This callback is used when twireshark wants us to draw/update our
+ * data to the output device. Since this is twireshark only output is
  * stdout.
- * Tethereal will only call this callback once, which is when tethereal has
+ * Twireshark will only call this callback once, which is when twireshark has
  * finished reading all packets and exists.
  * If used with wireshark this may be called any time, perhaps once every 3 
  * seconds or so.
@@ -268,7 +268,7 @@ rpcstat_find_procs(gpointer *key, gpointer *value _U_, gpointer *user_data _U_)
 /* When called, this function will create a new instance of rpcstat.
  * program and version are whick onc-rpc program/version we want to
  * collect statistics for.
- * This function is called from tethereal when it parses the -z rpc, arguments
+ * This function is called from twireshark when it parses the -z rpc, arguments
  * and it creates a new instance to store statistics in and registers this
  * new instance for the rpc tap.
  */
@@ -289,7 +289,7 @@ rpcstat_init(const char *optarg, void* userdata _U_)
                        filter=NULL;
                }
        } else {
-               fprintf(stderr, "tethereal: invalid \"-z rpc,rtt,<program>,<version>[,<filter>]\" argument\n");
+               fprintf(stderr, "twireshark: invalid \"-z rpc,rtt,<program>,<version>[,<filter>]\" argument\n");
                exit(1);
        }
 
@@ -309,8 +309,8 @@ rpcstat_init(const char *optarg, void* userdata _U_)
        rpc_max_proc=-1;
        g_hash_table_foreach(rpc_procs, (GHFunc)rpcstat_find_procs, NULL);
        if(rpc_min_proc==-1){
-               fprintf(stderr,"tethereal: Invalid -z rpc,rrt,%d,%d\n",rpc_program,rpc_version);
-               fprintf(stderr,"   Program:%d version:%d isn't supported by tethereal.\n", rpc_program, rpc_version);
+               fprintf(stderr,"twireshark: Invalid -z rpc,rrt,%d,%d\n",rpc_program,rpc_version);
+               fprintf(stderr,"   Program:%d version:%d isn't supported by twireshark.\n", rpc_program, rpc_version);
                exit(1);
        }
 
@@ -345,7 +345,7 @@ rpcstat_init(const char *optarg, void* userdata _U_)
                g_free(rs->filter);
                g_free(rs);
 
-               fprintf(stderr, "tethereal: Couldn't register rpc,rtt tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register rpc,rtt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 2971abf9c18907d6988db6a220fe204da969900b..305e2a08aaff821d4bff99353d581e0ceaf6a9fe 100644 (file)
@@ -1,5 +1,5 @@
 /* tap_sctpchunkstat.c
- * SCTP chunk counter for ethereal
+ * SCTP chunk counter for wireshark
  * Copyright 2005 Oleg Terletsky <oleg.terletsky@comverse.com>
  *
  * $Id$
@@ -246,7 +246,7 @@ sctpstat_init(const char *optarg, void* userdata _U_)
                g_free(hs->filter);
                g_free(hs);
 
-               fprintf(stderr, "tethereal: Couldn't register sctp,stat tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register sctp,stat tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index df24c452b28636a0d06f842a00189d7d43960e89..0203a977cd304625147ae54a6206af437d6802ba 100644 (file)
@@ -1,5 +1,5 @@
 /* tap_sipstat.c
- * sip message counter for ethereal
+ * sip message counter for wireshark
  *
  * $Id$
  * Copied from gtk/sip_stat.c and tap-httpstat.c
@@ -378,7 +378,7 @@ sipstat_init(const char *optarg, void* userdata _U_)
                /* error, we failed to attach to the tap. clean up */
                g_free(sp->filter);
                g_free(sp);
-               fprintf (stderr, "tethereal: Couldn't register sip,stat tap: %s\n",
+               fprintf (stderr, "twireshark: Couldn't register sip,stat tap: %s\n",
                                error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index a9192344ac65752170b58ded0a4b01401e740381..6e39ec38e9630792e884b76717c97ebbaf4a2106 100644 (file)
@@ -78,14 +78,14 @@ smbsids_init(const char *optarg _U_, void* userdata _U_)
                fprintf(stderr,"Either enable Edit/Preferences/Protocols/SMB/Snoop SID name mappings  in wireshark\n");
                fprintf(stderr,"or override the preference file by specifying\n");
                fprintf(stderr,"  -o \"smb.sid_name_snooping=TRUE\"\n");
-               fprintf(stderr,"on the tethereal command line.\n");
+               fprintf(stderr,"on the twireshark command line.\n");
                exit(1);
        }
 
 
        error_string=register_tap_listener("smb", NULL, NULL, NULL, smbsids_packet, smbsids_draw);
        if(error_string){
-               fprintf(stderr, "tethereal: Couldn't register smb,sids tap:%s\n",
+               fprintf(stderr, "twireshark: Couldn't register smb,sids tap:%s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 040b88a9a798fded9349b52d2201a0a6674e1b12..8f6dc2328964e72de7a072deb7a768b4d1d7546e 100644 (file)
@@ -265,7 +265,7 @@ smbstat_init(const char *optarg,void* userdata _U_)
                g_free(ss->filter);
                g_free(ss);
 
-               fprintf(stderr, "tethereal: Couldn't register smb,rtt tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register smb,rtt tap: %s\n",
                    error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index 09b50a4a890fe75c300c52d6ae652ecb02c4bf1e..7c60799e5893f4549e6f2ff001bc90042e27a19b 100644 (file)
@@ -1,5 +1,5 @@
 /* tap-stats_tree.c
- * tethereal's tap implememntation of stats_tree
+ * twireshark's tap implememntation of stats_tree
  * 2005, Luis E. G. Ontanon
  *
  * $Id$
index f6e2efe871fe2eaf886d2c16e018cd607c2e3acc..b99061dc01adbea98fddc5f799f5f5971232769b 100644 (file)
@@ -22,8 +22,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
-/* This module provides WSP  statistics to tethereal.
- * It is only used by tethereal and not ethereal
+/* This module provides WSP  statistics to twireshark.
+ * It is only used by twireshark and not wireshark
  *
  */
 
@@ -168,10 +168,10 @@ wspstat_packet(void *psp, packet_info *pinfo _U_, epan_dissect_t *edt _U_, const
 }
 
 
-/* This callback is used when tethereal wants us to draw/update our
- * data to the output device. Since this is tethereal only output is
+/* This callback is used when twireshark wants us to draw/update our
+ * data to the output device. Since this is twireshark only output is
  * stdout.
- * Tethereal will only call this callback once, which is when tethereal has
+ * Twireshark will only call this callback once, which is when twireshark has
  * finished reading all packets and exists.
  * If used with wireshark this may be called any time, perhaps once every 3 
  * seconds or so.
@@ -209,7 +209,7 @@ wspstat_draw(void *psp)
 /* When called, this function will create a new instance of wspstat.
  * program and version are whick onc-rpc program/version we want to
  * collect statistics for.
- * This function is called from tethereal when it parses the -z wsp, arguments
+ * This function is called from twireshark when it parses the -z wsp, arguments
  * and it creates a new instance to store statistics in and registers this
  * new instance for the wsp tap.
  */
@@ -272,7 +272,7 @@ wspstat_init(const char *optarg, void* userdata _U_)
                g_free(sp);
                g_hash_table_foreach( sp->hash, (GHFunc) wsp_free_hash_table, NULL ) ;
                g_hash_table_destroy( sp->hash );
-               fprintf(stderr, "tethereal: Couldn't register wsp,stat tap: %s\n",
+               fprintf(stderr, "twireshark: Couldn't register wsp,stat tap: %s\n",
                                error_string->str);
                g_string_free(error_string, TRUE);
                exit(1);
index a9282f72ebbfc073dd9bd4dee4d46ecc58c5d283..e4a274241d4458a0ad0657541c0a7616c2ead752 100644 (file)
@@ -1,4 +1,4 @@
-/* tethereal.c
+/* twireshark.c
  *
  * $Id$
  *
@@ -216,9 +216,9 @@ print_usage(gboolean print_ver)
   if (print_ver) {
     output = stdout;
     fprintf(output, 
-        "Tethereal " VERSION "%s\n"
+        "Twireshark " VERSION "%s\n"
         "Dump and analyze network traffic.\n"
-        "See http://www.ethereal.com for more information.\n"
+        "See http://www.wireshark.com for more information.\n"
         "\n"
         "%s",
        svnversion, get_copyright_info());
@@ -226,7 +226,7 @@ print_usage(gboolean print_ver)
     output = stderr;
   }
   fprintf(output, "\n");
-  fprintf(output, "Usage: tethereal [options] ...\n");
+  fprintf(output, "Usage: twireshark [options] ...\n");
   fprintf(output, "\n");
 
 #ifdef HAVE_LIBPCAP
@@ -1030,7 +1030,7 @@ main(int argc, char *argv[])
         }
         break;
       case 'v':        /* Show version and exit */
-        printf("Tethereal " VERSION "%s\n"
+        printf("Twireshark " VERSION "%s\n"
                "\n"
                "%s"
                "\n"
@@ -1123,7 +1123,7 @@ main(int argc, char *argv[])
 
 #ifndef HAVE_LIBPCAP
   if (capture_option_specified)
-    cmdarg_err("This version of Tethereal was not built with support for capturing packets.");
+    cmdarg_err("This version of Twireshark was not built with support for capturing packets.");
 #endif
   if (arg_error) {
     print_usage(FALSE);
@@ -1385,7 +1385,7 @@ main(int argc, char *argv[])
 
     /*
      * Immediately relinquish any special privileges we have; we must not
-     * be allowed to read any capture files the user running Tethereal
+     * be allowed to read any capture files the user running Twireshark
      * can't open.
      */
     relinquish_special_privs_perm();
@@ -1438,7 +1438,7 @@ main(int argc, char *argv[])
       char *detailed_err;
 
       cmdarg_err("WinPcap couldn't be found.");
-      detailed_err = cant_load_winpcap_err("Tethereal");
+      detailed_err = cant_load_winpcap_err("Twireshark");
       cmdarg_err_cont("%s", detailed_err);
       g_free(detailed_err);
       exit(2);
@@ -1481,7 +1481,7 @@ main(int argc, char *argv[])
     }
 #else
     /* No - complain. */
-    cmdarg_err("This version of Tethereal was not built with support for capturing packets.");
+    cmdarg_err("This version of Twireshark was not built with support for capturing packets.");
     exit(2);
 #endif
   }
@@ -1981,13 +1981,13 @@ capture_cleanup(DWORD ctrltype _U_)
      no other handler - such as one that would terminate the process -
      gets called.
 
-     XXX - for some reason, typing ^C to Tethereal, if you run this in
+     XXX - for some reason, typing ^C to Twireshark, if you run this in
      a Cygwin console window in at least some versions of Cygwin,
-     causes Tethereal to terminate immediately; this routine gets
+     causes Twireshark to terminate immediately; this routine gets
      called, but the main loop doesn't get a chance to run and
      exit cleanly, at least if this is compiled with Microsoft Visual
      C++ (i.e., it's a property of the Cygwin console window or Bash;
-     it happens if Tethereal is not built with Cygwin - for all I know,
+     it happens if Twireshark is not built with Cygwin - for all I know,
      building it with Cygwin may make the problem go away). */
   ld.go = FALSE;
   return TRUE;
@@ -2130,7 +2130,7 @@ load_cap_file(capture_file *cf, char *save_file, int out_file_type)
     switch (err) {
 
     case WTAP_ERR_UNSUPPORTED_ENCAP:
-      cmdarg_err("\"%s\" has a packet with a network type that Tethereal doesn't support.\n(%s)",
+      cmdarg_err("\"%s\" has a packet with a network type that Twireshark doesn't support.\n(%s)",
                  cf->filename, err_info);
       break;
 
@@ -2334,7 +2334,7 @@ process_packet(capture_file *cf, long offset, const struct wtap_pkthdr *whdr,
          tree for a single packet without waiting for anything to happen,
          it should be as good as line-buffered mode if we're printing
          protocol trees.  (The whole reason for the "-l" flag in either
-         tcpdump or Tethereal is to allow the output of a live capture to
+         tcpdump or Twireshark is to allow the output of a live capture to
          be piped to a program or script and to have that script see the
          information for the packet as soon as it's printed, rather than
          having to wait until a standard I/O buffer fills up. */
@@ -2798,13 +2798,13 @@ cf_open_error_message(int err, gchar *err_info, gboolean for_writing,
 
     case WTAP_ERR_FILE_UNKNOWN_FORMAT:
       /* Seen only when opening a capture file for reading. */
-      errmsg = "The file \"%s\" isn't a capture file in a format Tethereal understands.";
+      errmsg = "The file \"%s\" isn't a capture file in a format Twireshark understands.";
       break;
 
     case WTAP_ERR_UNSUPPORTED:
       /* Seen only when opening a capture file for reading. */
       g_snprintf(errmsg_errno, sizeof(errmsg_errno),
-               "The file \"%%s\" isn't a capture file in a format Tethereal understands.\n"
+               "The file \"%%s\" isn't a capture file in a format Twireshark understands.\n"
                "(%s)", err_info);
       g_free(err_info);
       errmsg = errmsg_errno;
@@ -2820,15 +2820,15 @@ cf_open_error_message(int err, gchar *err_info, gboolean for_writing,
 
     case WTAP_ERR_UNSUPPORTED_FILE_TYPE:
       /* Seen only when opening a capture file for writing. */
-      errmsg = "Tethereal doesn't support writing capture files in that format.";
+      errmsg = "Twireshark doesn't support writing capture files in that format.";
       break;
 
     case WTAP_ERR_UNSUPPORTED_ENCAP:
       if (for_writing)
-        errmsg = "Tethereal can't save this capture in that format.";
+        errmsg = "Twireshark can't save this capture in that format.";
       else {
         g_snprintf(errmsg_errno, sizeof(errmsg_errno),
-                 "The file \"%%s\" is a capture for a network type that Tethereal doesn't support.\n"
+                 "The file \"%%s\" is a capture for a network type that Twireshark doesn't support.\n"
                  "(%s)", err_info);
         g_free(err_info);
         errmsg = errmsg_errno;
@@ -2837,9 +2837,9 @@ cf_open_error_message(int err, gchar *err_info, gboolean for_writing,
 
     case WTAP_ERR_ENCAP_PER_PACKET_UNSUPPORTED:
       if (for_writing)
-        errmsg = "Tethereal can't save this capture in that format.";
+        errmsg = "Twireshark can't save this capture in that format.";
       else
-        errmsg = "The file \"%s\" is a capture for a network type that Tethereal doesn't support.";
+        errmsg = "The file \"%s\" is a capture for a network type that Twireshark doesn't support.";
       break;
 
     case WTAP_ERR_BAD_RECORD:
@@ -2881,12 +2881,12 @@ cf_open_error_message(int err, gchar *err_info, gboolean for_writing,
 }
 
 /*
- * Open/create errors are reported with an console message in Tethereal.
+ * Open/create errors are reported with an console message in Twireshark.
  */
 static void
 open_failure_message(const char *filename, int err, gboolean for_writing)
 {
-  fprintf(stderr, "tethereal: ");
+  fprintf(stderr, "twireshark: ");
   fprintf(stderr, file_open_error_message(err, for_writing), filename);
   fprintf(stderr, "\n");
 }
@@ -2947,18 +2947,18 @@ fail:
 
 
 /*
- * General errors are reported with an console message in Tethereal.
+ * General errors are reported with an console message in Twireshark.
  */
 static void
 failure_message(const char *msg_format, va_list ap)
 {
-  fprintf(stderr, "tethereal: ");
+  fprintf(stderr, "twireshark: ");
   vfprintf(stderr, msg_format, ap);
   fprintf(stderr, "\n");
 }
 
 /*
- * Read errors are reported with an console message in Tethereal.
+ * Read errors are reported with an console message in Twireshark.
  */
 static void
 read_failure_message(const char *filename, int err)
@@ -2976,7 +2976,7 @@ cmdarg_err(const char *fmt, ...)
   va_list ap;
 
   va_start(ap, fmt);
-  fprintf(stderr, "tethereal: ");
+  fprintf(stderr, "twireshark: ");
   vfprintf(stderr, fmt, ap);
   fprintf(stderr, "\n");
   va_end(ap);
index 88868e81c858b7cb27d5fa30add7e5baec5b0e02..b6c270ce5cac8002ae2206028b45283a900c414f 100644 (file)
@@ -994,7 +994,7 @@ usage (void)
 #endif
             "\n"
             "Generate a capture file from an ASCII hexdump of packets.\n"
-            "See http://www.ethereal.com for more information.\n"
+            "See http://www.wireshark.org for more information.\n"
             "\n"
             "Usage: text2pcap [options] <input-filename> <output-filename>\n"
             "\n"
index b25e3905df2d101eebc2bf0dd12d4cdfb7a19c04..dc8721e652cc7b1c1cbd0fbe0f2c2d3667de41d2 100644 (file)
@@ -247,7 +247,7 @@ get_runtime_version_info(GString *str)
         * flavor of Windows on which you're running.  Implementing more
         * of that is left as an exercise to the reader - who should
         * check any copyright information about code samples on MSDN
-        * before cutting and pasting into Ethereal.
+        * before cutting and pasting into Wireshark.
         *
         * They should also note that you need an OSVERSIONINFOEX structure
         * to get some of that information, and that not only is that
--- a/capture.c
+++ b/capture.c
@@ -225,7 +225,7 @@ guint32 drops)
 "\n"
 "Help about capturing can be found at:\n"
 "\n"
-"       http://wiki.ethereal.com/CaptureSetup"
+"       http://wiki.wireshark.org/CaptureSetup"
 #ifdef _WIN32
 "\n\n"
 "Wireless (Wi-Fi/WLAN):\n"
@@ -494,7 +494,7 @@ capture_input_closed(capture_options *capture_opts)
 "\n"
 "Help about capturing can be found at:\n"
 "\n"
-"       http://wiki.ethereal.com/CaptureSetup"
+"       http://wiki.wireshark.org/CaptureSetup"
 #ifdef _WIN32
 "\n\n"
 "Wireless (Wi-Fi/WLAN):\n"
index ddbd84781016a60658096769a57428caafd0a611..0d55e76dbf30675277bbc12606f9e9fe87adce88 100644 (file)
@@ -47,7 +47,7 @@ cant_load_winpcap_err(const char *app_name)
 "\n"
 "or the mirror at\n"
 "\n"
-"        http://winpcap.mirror.ethereal.com/\n"
+"        http://winpcap.mirror.wireshark.org/\n"
 "\n"
 "or the mirror at\n"
 "\n"
index c2e66fb13a14923980f73c8bc831f93f716a66be..5206230676f945d086635fb5addceead855cb0bc 100644 (file)
@@ -113,13 +113,13 @@ cf_open_error_message(int err, gchar *err_info, gboolean for_writing,
 
     case WTAP_ERR_FILE_UNKNOWN_FORMAT:
       /* Seen only when opening a capture file for reading. */
-      errmsg = "The file \"%s\" isn't a capture file in a format Tethereal understands.";
+      errmsg = "The file \"%s\" isn't a capture file in a format Twireshark understands.";
       break;
 
     case WTAP_ERR_UNSUPPORTED:
       /* Seen only when opening a capture file for reading. */
       g_snprintf(errmsg_errno, sizeof(errmsg_errno),
-               "The file \"%%s\" isn't a capture file in a format Tethereal understands.\n"
+               "The file \"%%s\" isn't a capture file in a format Twireshark understands.\n"
                "(%s)", err_info);
       g_free(err_info);
       errmsg = errmsg_errno;
@@ -135,15 +135,15 @@ cf_open_error_message(int err, gchar *err_info, gboolean for_writing,
 
     case WTAP_ERR_UNSUPPORTED_FILE_TYPE:
       /* Seen only when opening a capture file for writing. */
-      errmsg = "Tethereal doesn't support writing capture files in that format.";
+      errmsg = "Twireshark doesn't support writing capture files in that format.";
       break;
 
     case WTAP_ERR_UNSUPPORTED_ENCAP:
       if (for_writing)
-        errmsg = "Tethereal can't save this capture in that format.";
+        errmsg = "Twireshark can't save this capture in that format.";
       else {
         g_snprintf(errmsg_errno, sizeof(errmsg_errno),
-                 "The file \"%%s\" is a capture for a network type that Tethereal doesn't support.\n"
+                 "The file \"%%s\" is a capture for a network type that Twireshark doesn't support.\n"
                  "(%s)", err_info);
         g_free(err_info);
         errmsg = errmsg_errno;
@@ -152,9 +152,9 @@ cf_open_error_message(int err, gchar *err_info, gboolean for_writing,
 
     case WTAP_ERR_ENCAP_PER_PACKET_UNSUPPORTED:
       if (for_writing)
-        errmsg = "Tethereal can't save this capture in that format.";
+        errmsg = "Twireshark can't save this capture in that format.";
       else
-        errmsg = "The file \"%s\" is a capture for a network type that Tethereal doesn't support.";
+        errmsg = "The file \"%s\" is a capture for a network type that Twireshark doesn't support.";
       break;
 
     case WTAP_ERR_BAD_RECORD:
index bfcd67b294e1673f532e6b3090210068533e77a6..92b626353b8f1d73b8d0a1d3464307ce36868098 100644 (file)
@@ -3,7 +3,7 @@
  *
  * $Id$
  *
* Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
@@ -165,7 +165,7 @@ cap_pipe_open_live(char *pipename, struct pcap_hdr *hdr, loop_data *ld,
   g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_DEBUG, "cap_pipe_open_live: %s", pipename);
 
   /*
* XXX (T)Ethereal blocks until we return
    */
   if (strcmp(pipename, "-") == 0)
     fd = 0; /* read from stdin */
@@ -458,7 +458,7 @@ capture_loop_open_input(capture_options *capture_opts, loop_data *ld,
   g_log(LOG_DOMAIN_CAPTURE_CHILD, G_LOG_LEVEL_DEBUG, "capture_loop_open_input : %s", capture_opts->iface);
 
 
/* XXX - opening Winsock on tethereal? */
 
   /* Initialize Windows Socket if we are in a WIN32 OS
      This needs to be done before querying the interface for network/netmask */
@@ -567,7 +567,7 @@ capture_loop_open_input(capture_options *capture_opts, loop_data *ld,
 "\n"
 "Help can be found at:\n"
 "\n"
-"       http://wiki.ethereal.com/CaptureSetup\n"
+"       http://wiki.wireshark.org/CaptureSetup\n"
 "\n"
 "64-bit Windows:\n"
 "WinPcap does not support 64-bit Windows; you will have to use some other\n"
@@ -592,16 +592,16 @@ capture_loop_open_input(capture_options *capture_opts, loop_data *ld,
        /* Pipe doesn't exist, so output message for interface */
 
        /* If we got a "can't find PPA for X" message, warn the user (who
-          is running (T)Ethereal on HP-UX) that they don't have a version
+          is running (T)Wireshark on HP-UX) that they don't have a version
           of libpcap that properly handles HP-UX (libpcap 0.6.x and later
           versions, which properly handle HP-UX, say "can't find /dev/dlpi
           PPA for X" rather than "can't find PPA for X"). */
        if (strncmp(open_err_str, ppamsg, sizeof ppamsg - 1) == 0)
          libpcap_warn =
            "\n\n"
-           "You are running (T)Ethereal with a version of the libpcap library\n"
+           "You are running (T)Wireshark with a version of the libpcap library\n"
            "that doesn't handle HP-UX network devices well; this means that\n"
-           "(T)Ethereal may not be able to capture packets.\n"
+           "(T)Wireshark may not be able to capture packets.\n"
            "\n"
            "To fix this, you should install libpcap 0.6.2, or a later version\n"
            "of libpcap, rather than libpcap 0.4 or 0.5.x.  It is available in\n"
@@ -628,7 +628,7 @@ capture_loop_open_input(capture_options *capture_opts, loop_data *ld,
 #endif
   }
 
/* XXX - will this work for tethereal? */
 #ifdef MUST_DO_SELECT
   if (!ld->from_cap_pipe) {
 #ifdef HAVE_PCAP_GET_SELECTABLE_FD
@@ -753,7 +753,7 @@ gboolean capture_loop_init_output(capture_options *capture_opts, int save_file_f
 
   if (ld->pdh == NULL) {
     /* We couldn't set up to write to the capture file. */
/* XXX - use cf_open_error_message from tethereal instead? */
     switch (err) {
 
     case WTAP_ERR_CANT_OPEN:
@@ -854,7 +854,7 @@ capture_loop_dispatch(capture_options *capture_opts _U_, loop_data *ld,
      * to stop a capture until a packet arrives.  If that's unacceptable,
      * plead with whoever supplies the software for that device to add
      * "select()" support, or upgrade to libpcap 0.8.1 or later, and
* rebuild Ethereal or get a version built with libpcap 0.8.1 or
      * later, so it can use pcap_breakloop().
      */
 #ifdef LOG_CAPTURE_VERBOSE
@@ -923,7 +923,7 @@ capture_loop_dispatch(capture_options *capture_opts _U_, loop_data *ld,
 
       /*
        * WinPcap's remote capturing feature doesn't work with pcap_dispatch(),
-       * see http://wiki.ethereal.com/CaptureSetup_2fWinPcapRemote
+       * see http://wiki.wireshark.org/CaptureSetup_2fWinPcapRemote
        * This should be fixed in the WinPcap 4.0 alpha release.
        *
        * For reference, an example remote interface:
index ab6221dbf85201b82bb1530463388df033f0db25..83b6b7e055fd1911e79e31a07e6183bd22a29f89 100644 (file)
@@ -3,7 +3,7 @@
  *
  * $Id$
  *
* Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
  *
@@ -98,9 +98,9 @@ extern void capture_loop_stop(void);
 typedef void (*capture_packet_cb_fct)(u_char *, const struct pcap_pkthdr *, const u_char *);
 
 
/* moved from capture_loop.c here, so we can combine it (and the related functions) with tethereal */
 /* XXX - should be moved back to capture_loop.c */
/* E: capture_loop.c only (Ethereal/dumpcap) T: tethereal only */
 typedef struct _loop_data {
   /* common */
   gboolean       go;                    /* TRUE as long as we're supposed to keep capturing */
index 81be81a59b47f41db9498720c955b5948157853c..3056af800e982445738a283e8833ec22c8731335 100644 (file)
@@ -244,7 +244,7 @@ capture_opts_add_iface_opt(capture_options *capture_opts, const char *optarg)
 
     /*
      * If the argument is a number, treat it as an index into the list
* of adapters, as printed by "tethereal -D".
      *
      * This should be OK on UNIX systems, as interfaces shouldn't have
      * names that begin with digits.  It can be useful on Windows, where
index 65109da4afb1a37be7062695c14673cfc70ffbd1..ba435e0bf9be6e904889afc48c942807966c6393 100644 (file)
@@ -1,5 +1,5 @@
 /* capture_sync.c
* Synchronisation between Ethereal capture parent and child instances
  *
  * $Id$
  *
@@ -265,7 +265,7 @@ sync_pipe_start(capture_options *capture_opts) {
     argv = g_malloc(sizeof (char *));
     *argv = NULL;
 
/* take ethereal's absolute program path and replace "ethereal" with "dumpcap" */
     exename = g_strdup_printf("%s" G_DIR_SEPARATOR_S "dumpcap", progfile_dir);
 
     /* Make that the first argument in the argument list (argv[0]). */
@@ -445,7 +445,7 @@ sync_pipe_start(capture_options *capture_opts) {
 
     if ((capture_opts->fork_child = fork()) == 0) {
       /*
* Child process - run Ethereal with the right arguments to make
        * it just pop up the live capture dialog box and capture with
        * the specified capture parameters, writing to the specified file.
        */
@@ -895,7 +895,7 @@ sync_pipe_stop(capture_options *capture_opts)
 }
 
 
/* Ethereal has to exit, force the capture child to close */
 void
 sync_pipe_kill(capture_options *capture_opts)
 {
index be1ca3710b749dbfa7cea87eb300d6c17c68526e..a8b6e6edafae550adc4dd1ef618dbe4da1b2e717 100644 (file)
@@ -1,5 +1,5 @@
 /* capture_sync.h
* Synchronisation between Ethereal capture parent and child instances
  *
  * $Id$
  *
@@ -27,7 +27,7 @@
  *  
  *  Sync mode capture (internal interface).
  *
*  Will start a new Ethereal child instance which will do the actual capture 
  *  work.
  */
 
index 686911e476dafaa186b24ad8a73c44a6bbc65935..7034b5d9e26c14295355141758d66103d6a6f6b2 100644 (file)
@@ -1,7 +1,7 @@
 /* capture_wpcap_packet.c
  * WinPcap-specific interfaces for low-level information (packet.dll).  
  * We load WinPcap at run
* time, so that we only need one Ethereal binary and one Tethereal binary
  * for Windows, regardless of whether WinPcap is installed or not.
  *
  * $Id$
index a653c495f553f910d19f0bf891fc5bff3f3825b0..ef756574a7c16bc5664dc27d5c731bcc8b01c34e 100644 (file)
@@ -1,5 +1,5 @@
 /* clopts_common.c
* Handle command-line arguments common to Ethereal and Tethereal
  *
  * $Id$
  *
index 261e8bf792fac0598a912949c5e59bbc972b60ab..584ddc2cbc31f0a6ecc94e13333d43101adea364 100644 (file)
@@ -1,5 +1,5 @@
 /* clopts_common.h
* Handle command-line arguments common to Ethereal and Tethereal
  *
  * $Id$
  *
@@ -3,7 +3,7 @@
  * $Id$
  *
- * Ethereal - Network traffic analyzer
+ * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
@@ -165,7 +165,7 @@ cap_pipe_open_live(char *pipename, struct pcap_hdr *hdr, loop_data *ld,
 
   /*
-   * XXX (T)Ethereal blocks until we return
+   * XXX (T)Wireshark blocks until we return
    */
   if (strcmp(pipename, "-") == 0)
@@ -458,7 +458,7 @@ capture_loop_open_input(capture_options *capture_opts, loop_data *ld,
 
 
-/* XXX - opening Winsock on tethereal? */
+/* XXX - opening Winsock on twireshark? */
 
   /* Initialize Windows Socket if we are in a WIN32 OS
@@ -628,7 +628,7 @@ capture_loop_open_input(capture_options *capture_opts, loop_data *ld,
   }
 
-/* XXX - will this work for tethereal? */
+/* XXX - will this work for twireshark? */
 #ifdef MUST_DO_SELECT
   if (!ld->from_cap_pipe) {
@@ -753,7 +753,7 @@ gboolean capture_loop_init_output(capture_options *capture_opts, int save_file_f
   if (ld->pdh == NULL) {
     /* We couldn't set up to write to the capture file. */
-    /* XXX - use cf_open_error_message from tethereal instead? */
+    /* XXX - use cf_open_error_message from twireshark instead? */
     switch (err) {
 
@@ -854,7 +854,7 @@ capture_loop_dispatch(capture_options *capture_opts _U_, loop_data *ld,
      * plead with whoever supplies the software for that device to add
      * "select()" support, or upgrade to libpcap 0.8.1 or later, and
-     * rebuild Ethereal or get a version built with libpcap 0.8.1 or
+     * rebuild Wireshark or get a version built with libpcap 0.8.1 or
      * later, so it can use pcap_breakloop().
      */
@@ -3,7 +3,7 @@
  * $Id$
  *
- * Ethereal - Network traffic analyzer
+ * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
  * Copyright 1998 Gerald Combs
@@ -98,9 +98,9 @@ extern void capture_loop_stop(void);
 
 
-/* moved from capture_loop.c here, so we can combine it (and the related functions) with tethereal */
+/* moved from capture_loop.c here, so we can combine it (and the related functions) with twireshark */
 /* XXX - should be moved back to capture_loop.c */
@@ -98,9 +98,9 @@ extern void capture_loop_stop(void);
 /* XXX - should be moved back to capture_loop.c */
-/* E: capture_loop.c only (Ethereal/dumpcap) T: tethereal only */
+/* E: capture_loop.c only (Wireshark/dumpcap) T: twireshark only */
 typedef struct _loop_data {
   /* common */
@@ -244,7 +244,7 @@ capture_opts_add_iface_opt(capture_options *capture_opts, const char *optarg)
     /*
      * If the argument is a number, treat it as an index into the list
-     * of adapters, as printed by "tethereal -D".
+     * of adapters, as printed by "twireshark -D".
      *
      * This should be OK on UNIX systems, as interfaces shouldn't have
@@ -1,5 +1,5 @@
 /* capture_sync.c
- * Synchronisation between Ethereal capture parent and child instances
+ * Synchronisation between Wireshark capture parent and child instances
  *
  * $Id$
@@ -265,7 +265,7 @@ sync_pipe_start(capture_options *capture_opts) {
     *argv = NULL;
 
-    /* take ethereal's absolute program path and replace "ethereal" with "dumpcap" */
+    /* take Wireshark's absolute program path and replace "Wireshark" with "dumpcap" */
     exename = g_strdup_printf("%s" G_DIR_SEPARATOR_S "dumpcap", progfile_dir);
 
@@ -445,7 +445,7 @@ sync_pipe_start(capture_options *capture_opts) {
     if ((capture_opts->fork_child = fork()) == 0) {
       /*
-       * Child process - run Ethereal with the right arguments to make
+       * Child process - run Wireshark with the right arguments to make
        * it just pop up the live capture dialog box and capture with
        * the specified capture parameters, writing to the specified file.
@@ -895,7 +895,7 @@ sync_pipe_stop(capture_options *capture_opts)
 
 
-/* Ethereal has to exit, force the capture child to close */
+/* Wireshark has to exit, force the capture child to close */
 void
 sync_pipe_kill(capture_options *capture_opts)
@@ -1,5 +1,5 @@
 /* capture_sync.h
- * Synchronisation between Ethereal capture parent and child instances
+ * Synchronisation between Wireshark capture parent and child instances
  *
  * $Id$
@@ -27,7 +27,7 @@
  *  Sync mode capture (internal interface).
  *
- *  Will start a new Ethereal child instance which will do the actual capture 
+ *  Will start a new Wireshark child instance which will do the actual capture 
  *  work.
  */
@@ -1,7 +1,7 @@
  * WinPcap-specific interfaces for low-level information (packet.dll).  
  * We load WinPcap at run
- * time, so that we only need one Ethereal binary and one Tethereal binary
+ * time, so that we only need one Wireshark binary and one Twireshark binary
  * for Windows, regardless of whether WinPcap is installed or not.
  *
@@ -1,5 +1,5 @@
 /* clopts_common.c
- * Handle command-line arguments common to Ethereal and Tethereal
+ * Handle command-line arguments common to Wireshark and Twireshark
  *
  * $Id$
@@ -1,5 +1,5 @@
 /* clopts_common.h
- * Handle command-line arguments common to Ethereal and Tethereal
+ * Handle command-line arguments common to Wireshark and Twireshark
  *
  * $Id$
index e358f84432ca06ee0239bc1dac718f7e143532c8..8136eaebd4f8401bfbaab0fee10501cf4fa690db 100644 (file)
--- a/dumpcap.c
+++ b/dumpcap.c
@@ -68,7 +68,7 @@
 
 /*#define DEBUG_DUMPCAP*/
 
-gboolean capture_child = FALSE; /* FALSE: standalone call, TRUE: this is an Ethereal capture child */
+gboolean capture_child = FALSE; /* FALSE: standalone call, TRUE: this is an Wireshark capture child */
 
 static void
 console_log_handler(const char *log_domain, GLogLevelFlags log_level,
@@ -96,7 +96,7 @@ print_usage(gboolean print_ver) {
     fprintf(output,
         "Dumpcap " VERSION "%s\n"
         "Capture network packets and dump them into a libpcap file.\n"
-        "See http://www.ethereal.com for more information.\n",
+        "See http://www.wireshark.org for more information.\n",
         svnversion);
   } else {
     output = stderr;
@@ -147,7 +147,7 @@ show_version(GString *comp_info_str, GString *runtime_info_str)
         "%s\n"
         "%s\n"
         "%s\n"
-        "See http://www.ethereal.com for more information.\n",
+        "See http://www.wireshark.org for more information.\n",
         svnversion, get_copyright_info() ,comp_info_str->str, runtime_info_str->str);
 }
 
@@ -343,7 +343,7 @@ main(int argc, char *argv[])
             exit_main(status);
         }
         break;
/*** hidden option: Ethereal child mode (using binary output messages) ***/
       case 'Z':
           capture_child = TRUE;
 #ifdef _WIN32
@@ -343,7 +343,7 @@ main(int argc, char *argv[])
         }
         break;
-      /*** hidden option: Ethereal child mode (using binary output messages) ***/
+      /*** hidden option: Wireshark child mode (using binary output messages) ***/
       case 'Z':
           capture_child = TRUE;
index 485cfdc84c25d45def0f74c3bb30abbe7f5985ae..1df5194c862412b8d9acb5cd92b7d1c7e87477d2 100644 (file)
diff --git a/file.c b/file.c
index e27dee26260b38b41c03aad2dcd515a8a19725ed..45d02b429038194a706eb21715dd9afd9bd093ba 100644 (file)
--- a/file.c
+++ b/file.c
@@ -507,7 +507,7 @@ cf_read(capture_file *cf)
 
     case WTAP_ERR_UNSUPPORTED_ENCAP:
       g_snprintf(errmsg_errno, sizeof(errmsg_errno),
-               "The capture file has a packet with a network type that Ethereal doesn't support.\n(%s)",
+               "The capture file has a packet with a network type that Wireshark doesn't support.\n(%s)",
                err_info);
       g_free(err_info);
       errmsg = errmsg_errno;
@@ -569,7 +569,7 @@ cf_continue_tail(capture_file *cf, int to_read, int *err)
 
   while (to_read != 0 && (wtap_read(cf->wth, err, &err_info, &data_offset))) {
     if (cf->state == FILE_READ_ABORTED) {
/* Well, the user decided to exit Ethereal.  Break out of the
          loop, and let the code below (which is called even if there
         aren't any packets left to read) exit. */
       break;
@@ -589,7 +589,7 @@ cf_continue_tail(capture_file *cf, int to_read, int *err)
   packet_list_thaw();
 
   if (cf->state == FILE_READ_ABORTED) {
/* Well, the user decided to exit Ethereal.  Return CF_READ_ABORTED
        so that our caller can kill off the capture child process;
        this will cause an EOF on the pipe from the child, so
        "cf_finish_tail()" will be called, and it will clean up
@@ -1136,7 +1136,7 @@ cf_merge_files(char **out_filenamep, int in_file_count,
 
        case WTAP_ERR_UNSUPPORTED_ENCAP:
          g_snprintf(errmsg_errno, sizeof(errmsg_errno),
-                  "The capture file %%s has a packet with a network type that Ethereal doesn't support.\n(%s)",
+                  "The capture file %%s has a packet with a network type that Wireshark doesn't support.\n(%s)",
                   err_info);
          g_free(err_info);
          errmsg = errmsg_errno;
@@ -1476,7 +1476,7 @@ rescan_packets(capture_file *cf, const char *action, const char *action_item,
        these frames, as they won't have been seen by this sequential
        pass, but the only alternative I see is to keep scanning them
        even though the user requested that the scan stop, and that
-       would leave the user stuck with an Ethereal grinding on
+       would leave the user stuck with an Wireshark grinding on
        until it finishes.  Should we just stick them with that? */
     for (; fdata != NULL; fdata = fdata->next) {
       fdata->flags.visited = 0;
@@ -3357,21 +3357,21 @@ cf_open_failure_alert_box(const char *filename, int err, gchar *err_info,
     case WTAP_ERR_RANDOM_OPEN_PIPE:
       /* Seen only when opening a capture file for reading. */
       simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                   "The file \"%s\" is a pipe or FIFO; Ethereal can't read pipe or FIFO files.",
+                   "The file \"%s\" is a pipe or FIFO; Wireshark can't read pipe or FIFO files.",
                    filename);
       break;
 
     case WTAP_ERR_FILE_UNKNOWN_FORMAT:
       /* Seen only when opening a capture file for reading. */
       simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                   "The file \"%s\" isn't a capture file in a format Ethereal understands.",
+                   "The file \"%s\" isn't a capture file in a format Wireshark understands.",
                    filename);
       break;
 
     case WTAP_ERR_UNSUPPORTED:
       /* Seen only when opening a capture file for reading. */
       simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                   "The file \"%s\" isn't a capture file in a format Ethereal understands.\n"
+                   "The file \"%s\" isn't a capture file in a format Wireshark understands.\n"
                    "(%s)",
                    filename, err_info);
       g_free(err_info);
@@ -3388,16 +3388,16 @@ cf_open_failure_alert_box(const char *filename, int err, gchar *err_info,
     case WTAP_ERR_UNSUPPORTED_FILE_TYPE:
       /* Seen only when opening a capture file for writing. */
       simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                   "Ethereal doesn't support writing capture files in that format.");
+                   "Wireshark doesn't support writing capture files in that format.");
       break;
 
     case WTAP_ERR_UNSUPPORTED_ENCAP:
       if (for_writing) {
        simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                     "Ethereal can't save this capture in that format.");
+                     "Wireshark can't save this capture in that format.");
       } else {
        simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                     "The file \"%s\" is a capture for a network type that Ethereal doesn't support.\n"
+                     "The file \"%s\" is a capture for a network type that Wireshark doesn't support.\n"
                      "(%s)",
                      filename, err_info);
         g_free(err_info);
@@ -3407,10 +3407,10 @@ cf_open_failure_alert_box(const char *filename, int err, gchar *err_info,
     case WTAP_ERR_ENCAP_PER_PACKET_UNSUPPORTED:
       if (for_writing) {
        simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                     "Ethereal can't save this capture in that format.");
+                     "Wireshark can't save this capture in that format.");
       } else {
        simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-                     "The file \"%s\" is a capture for a network type that Ethereal doesn't support.",
+                     "The file \"%s\" is a capture for a network type that Wireshark doesn't support.",
                      filename);
       }
       break;
@@ -3503,7 +3503,7 @@ cf_read_error_message(int err, const gchar *err_info)
 
   case WTAP_ERR_UNSUPPORTED_ENCAP:
       g_snprintf(errmsg_errno, sizeof(errmsg_errno),
-               "The file \"%%s\" has a packet with a network type that Ethereal doesn't support.\n(%s)",
+               "The file \"%%s\" has a packet with a network type that Wireshark doesn't support.\n(%s)",
                err_info);
       break;
 
@@ -569,7 +569,7 @@ cf_continue_tail(capture_file *cf, int to_read, int *err)
   while (to_read != 0 && (wtap_read(cf->wth, err, &err_info, &data_offset))) {
     if (cf->state == FILE_READ_ABORTED) {
-      /* Well, the user decided to exit Ethereal.  Break out of the
+      /* Well, the user decided to exit Wireshark.  Break out of the
          loop, and let the code below (which is called even if there
         aren't any packets left to read) exit. */
@@ -589,7 +589,7 @@ cf_continue_tail(capture_file *cf, int to_read, int *err)
 
   if (cf->state == FILE_READ_ABORTED) {
-    /* Well, the user decided to exit Ethereal.  Return CF_READ_ABORTED
+    /* Well, the user decided to exit Wireshark.  Return CF_READ_ABORTED
        so that our caller can kill off the capture child process;
        this will cause an EOF on the pipe from the child, so
index 297f67015885e81fb574b4e1f37e1e658a8af06e..1277a6c25fcdfdfe12da8836a734b7db848e3498 100644 (file)
--- a/isprint.h
+++ b/isprint.h
@@ -30,7 +30,7 @@
 /*
  * XXX - "isprint()" can return "true" for non-ASCII characters, but
  * those don't work with GTK+ 1.3 or later, as they take UTF-8 strings
* as input.  Until we fix up Ethereal to properly handle non-ASCII
  * characters in all output (both GUI displays and text printouts)
  * in those versions of GTK+, we work around the problem by escaping
  * all characters that aren't printable ASCII.
index 7003c2bf978b205b00942d6d2ab19bf3dbfa48ac..84fdbf3ee9c3847ac19270db78e5f09eab9e39f4 100644 (file)
@@ -93,7 +93,7 @@ usage(void)
 #endif
          "\n", VERSION);
   fprintf(stderr, "Merge two or more capture files into one.\n");
-  fprintf(stderr, "See http://www.ethereal.com for more information.\n");
+  fprintf(stderr, "See http://www.wireshark.org for more information.\n");
   fprintf(stderr, "\n");
   fprintf(stderr, "Usage: mergecap [options] -w <outfile|-> <infile> ...\n");
   fprintf(stderr, "\n");
@@ -30,7 +30,7 @@
  * XXX - "isprint()" can return "true" for non-ASCII characters, but
  * those don't work with GTK+ 1.3 or later, as they take UTF-8 strings
- * as input.  Until we fix up Ethereal to properly handle non-ASCII
+ * as input.  Until we fix up Wireshark to properly handle non-ASCII
  * characters in all output (both GUI displays and text printouts)
  * in those versions of GTK+, we work around the problem by escaping